@@ -25,30 +25,32 @@ ZIP <- function (mu.link = "log", sigma.link = "logit")
                          dldm}, 
     d2ldm2 = function(y,mu,sigma) {dldm0 <- -(1-sigma)*(((1-sigma)+sigma*exp(mu))^(-1))
                           dldm <- ifelse(y==0, dldm0, (y/mu)-1)
-                        d2ldm2 <- -dldm*dldm
-#  d2ldm2 <- (sigma*(1-sigma)*(((1-sigma)+sigma*exp(mu))^(-1)))-(1-sigma)/mu
+                        d2ldm2 <- -dldm*dldm        
+ # d2ldm2 <- (sigma*(1-sigma)*(((1-sigma)+sigma*exp(mu))^(-1)))-(1-sigma)/mu
+                        d2ldm2 <- ifelse(d2ldm2 < -1e-15, d2ldm2,-1e-15)  
                          d2ldm2},
      dldd = function(y,mu,sigma) {dldd0 <- (1-exp(-mu))*((sigma+(1-sigma)*exp(-mu))^(-1)) 
                          dldd <- ifelse(y==0, dldd0, -1/(1-sigma))
                          dldd}, 
     d2ldd2 = function(y,mu,sigma) {dldd0 <- (1-exp(-mu))*((sigma+(1-sigma)*exp(-mu))^(-1)) 
                           dldd <- ifelse(y==0, dldd0, -1/(1-sigma))
-                        d2ldd2 <- -dldd*dldd
-#                        py0 <- sigma+(1-sigma)*exp(-mu)
-#                        d2ldd2 <- -((1-exp(-mu))^2)*py0 - (1-py0)/((1-sigma)^2)
+                        d2ldd2 <- -dldd*dldd   
+                       # py0 <- sigma+(1-sigma)*exp(-mu)
+                       # d2ldd2 <- -((1-exp(-mu))^2)*py0 - (1-py0)/((1-sigma)^2)
+                        d2ldd2 <- ifelse(d2ldd2 < -1e-15, d2ldd2,-1e-15)  
                          d2ldd2},
   d2ldmdd = function(y,mu,sigma) {dldm0 <- -(1-sigma)*(((1-sigma)+sigma*exp(mu))^(-1))
                          dldm <- ifelse(y==0, dldm0, (y/mu)-1)
                         dldd0 <- (1-exp(-mu))*((sigma+(1-sigma)*exp(-mu))^(-1)) 
                          dldd <- ifelse(y==0, dldd0, -1/(1-sigma)) 
-                      d2ldmdd <- -dldm*dldd
-                      d2ldmdd                        
+                      d2ldmdd <- -dldm*dldd                     
 #d2ldmdd <- exp(-mu) + (1-sigma)*exp(-mu)*(1-exp(-mu))*((sigma+(1-sigma)*exp(-mu))^(-1))  
+                      d2ldmdd   
                        },
  G.dev.incr  = function(y,mu,sigma,...) -2*dZIP(y,mu,sigma,log=TRUE),                      
          rqres = expression(rqres(pfun="pZIP", type="Discrete", ymin=0, y=y, mu=mu, sigma=sigma)) ,
     mu.initial = expression(mu <- (y+mean(y))/2),     #rep(mean(y),length(y)) ), 
-   sigma.initial = expression(sigma <-rep(0.3, length(y))), 
+   sigma.initial = expression(sigma <-rep(0.1, length(y))), 
       mu.valid = function(mu) all(mu > 0) , 
    sigma.valid = function(sigma)  all(sigma > 0 & sigma < 1), 
        y.valid = function(y)  all(y >= 0)
@@ -87,8 +89,9 @@ qZIP <- function(p, mu = 5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
          if (any(p <= 0) | any(p >= 1))  stop(paste("p must be between 0 and 1", "\n", "")) 
          if (log.p == TRUE) p <- exp(p)   else p <- p
          if (lower.tail == TRUE)  p <- p  else p <- 1 - p
-          pnew <- (p-sigma)/(1-sigma)
-          suppressWarnings(q <- ifelse((pnew > 0 ), qpois(pnew, lambda = mu, ), 0))
+          pnew <- ((p-sigma)/(1-sigma))-(1e-7)# added Monday, March 15, 2010 
+          pnew <- ifelse(pnew > 0, pnew,0 )
+          q <- qpois(pnew, lambda = mu )
           q
    }
 #-----------------------------------------------------------------------------------------
